import { Plugin, PluginServiceApi, Builder } from '@cloudbase/framework-core';
/**
 * 导出接口用于生成 JSON Schema 来进行智能提示
 */
export interface IFrameworkPluginFunctionInputs {
    /**
     * 函数根目录
     * @default functions
     */
    functionRootPath?: string;
    /**
     * 云函数默认配置
     * CloudBaseFramework 1.6.1 以后支持
     * 单个函数的配置会在该默认配置的基础上进行 merge
     * @default {}
     */
    functionDefaultConfig?: ICloudFunction;
    /**
     * 函数配置数组
     */
    functions?: ICloudFunction[];
    /**
     *
     * 服务路径配置
     *
     * 如
     *
     * ```json
     * {
     *   "hello-world": "/helloworld"
     * }
     * ```
     */
    servicePaths?: Record<string, string>;
}
export interface IFunctionTriggerOptions {
    functionName: string;
    triggers?: ICloudFunctionTrigger[];
    triggerName?: string;
    envId: string;
}
export interface ICloudFunctionTrigger {
    name: string;
    type: string;
    config: string;
}
export interface ICloudFunction {
    /**
     * 云函数名称，即为函数部署后的名称
     */
    name: string;
    /**
     * 函数处理方法名称，名称格式支持“文件名称.函数名称”形式
     * @default index.main
     */
    handler?: string;
    /**
     * 函数超时时间（1 - 60S）
     */
    timeout?: number;
    /**
     * 包含环境变量的键值对
     */
    envVariables?: Record<string, string>;
    /**
     * 运行时环境配置，可选值： `Nodejs8.9, Nodejs10.15 Php7, Java8, Go1`
     * @default Nodejs10.15
     */
    runtime?: 'Nodejs10.15' | 'Nodejs8.9' | 'Php7' | 'Java8' | 'Go1';
    /**
     * 函数运行时内存配置
     * @default 128
     */
    memory?: 128 | 256 | 512 | 1024 | 2048;
    /**
     * VPC
     */
    vpc?: IFunctionVPC;
    /**
     * 是否云端安装依赖，目前仅支持 Node.js
     */
    installDependency?: boolean;
    isWaitInstall?: boolean;
    /**
     * 函数产物路径，相对于函数根目录 functionRootPath，例如 Go 语言可指定二进制文件路径，Java 可以指定 jar 包文件地址
     */
    functionDistPath?: string;
    /**
     * 忽略的文件
     */
    ignore?: string[];
    /**
     * 安全规则，配置前先阅读文档 https://docs.cloudbase.net/cloud-function/security-rules.html
     *
     * @example { invoke: true }
     */
    aclRule?: Record<string, any>;
    /**
     * 代码保护密钥，传入此参数将保护代码，在控制台/IDE中无法看到代码明文
     * 格式为 36 位大小字母和数字
     * @length 36
     * @pattern ^[a-zA-Z0-9]$
     */
    codeSecret?: string;
    /**
     * 是否自动创建新版本
     */
    bumpVersion?: boolean;
    /**
     * 函数触发器配置
     */
    triggers?: ICloudFunctionTrigger[];
}
export interface IFunctionVPC {
    /**
     * vpc 的id
     */
    vpcId: string;
    /**
     * 子网id
     */
    subnetId: string;
}
declare type ResolveInputs = IFrameworkPluginFunctionInputs & {
    functionRootPath: string;
    functions: ICloudFunction[];
    servicePaths: {};
};
declare class FunctionPlugin extends Plugin {
    name: string;
    api: PluginServiceApi;
    inputs: IFrameworkPluginFunctionInputs;
    protected resolvedInputs: ResolveInputs;
    protected buildOutput: any;
    protected functions: ICloudFunction[];
    protected functionRootPath: string;
    protected builder: FunctionBuilder;
    protected outputs: Record<string, any>;
    constructor(name: string, api: PluginServiceApi, inputs: IFrameworkPluginFunctionInputs);
    /**
     * 初始化
     */
    init(): Promise<void>;
    compile(): Promise<{
        EntryPoint: {
            Label: string;
            EntryType: string;
            HttpEntryPath: string;
        }[];
        Resources: Record<string, any>;
    }>;
    /**
     * 执行本地命令
     */
    run(): Promise<void>;
    /**
     * 删除资源
     */
    remove(): Promise<void>;
    /**
     * 生成代码
     */
    genCode(): Promise<void>;
    /**
     * 构建
     */
    build(): Promise<void>;
    /**
     * 部署
     */
    deploy(): Promise<void>;
    functionConfigToSAM(functionConfig: ICloudFunction): any;
    toConstantCase(name: string): string;
    genAclRule(functionConfig: ICloudFunction): string;
}
interface FunctionBuilderBuildOptions {
    name: string;
    localPath: string;
    zipFileName: string;
    ignore: string[];
    isNeedZip: boolean;
}
interface FunctionBuilderOptions {
    /**
     * 项目根目录的绝对路径
     */
    projectPath: string;
}
export declare class FunctionBuilder extends Builder {
    constructor(options: FunctionBuilderOptions);
    build(options: FunctionBuilderBuildOptions[]): Promise<{
        functions: {
            name: string;
            options: {};
            source: string;
            entry: string;
        }[];
    }>;
    zipFile(src: string, dest: string): Promise<unknown>;
    zipDir(src: string, dest: string, ignore?: string[]): Promise<unknown>;
}
export declare const plugin: typeof FunctionPlugin;
export {};
//# sourceMappingURL=index.d.ts.map